#[non_exhaustive]pub enum Error {
InvalidRequestException(InvalidRequestException),
ResourceNotFoundException(ResourceNotFoundException),
TooManyRequestsException(TooManyRequestsException),
UnauthorizedException(UnauthorizedException),
Unhandled(Unhandled),
}Expand description
All possible error types for this service.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidRequestException(InvalidRequestException)
Indicates that a problem occurred with the input to the request. For example, a required parameter might be missing or out of range.
ResourceNotFoundException(ResourceNotFoundException)
The specified resource doesn't exist.
TooManyRequestsException(TooManyRequestsException)
Indicates that the request is being made too frequently and is more than what the server can handle.
Indicates that the request is not authorized. This can happen due to an invalid access token in the request.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).